==> ui-hub-0.0.6.tgz: package/es/page-back-listener/index.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var flag = '$$_ui-hub_state';
;

var PageBackListener = function PageBackListener(cb) {
  var _this = this;

  _classCallCheck(this, PageBackListener);

  var currentState = window.history.state || {};
  var state = currentState[flag] || {};

  var pushState = function pushState() {
    window.history.pushState(_objectSpread(_objectSpread({}, currentState), {}, _defineProperty({}, flag, {
      stateBirth: true
    })), "");
  };
  /**
   * 对于该工具应用在多个页面的场景，如
   * A -> B -> C
   * 其中A B都应用了该监听，那么history：
   * [A, A(stateBirth: true), B, B(stateBirth: true), C]
   * 当 C 回退时， B 页面逻辑重新执行，这个场景下，不应该再产生新的state
   */


  if (!state.stateBirth) {
    pushState();
  }

  var listener = function listener() {
    cb(pushState);
  };

  window.addEventListener('popstate', listener); // 移除副作用

  this.removeEffect = function () {
    window.removeEventListener('popstate', listener);
  }; // 移除这整套机制


  this.removeListener = function () {
    _this.removeEffect();

    var currentState = window.history.state || {};
    var state = currentState[flag] || {};

    if (state.stateBirth) {
      window.history.go(-1);
    }
  };
};

export default PageBackListener;

==> ui-hub-0.0.9.tgz: package/es/page-back-listener/index.js <==
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _defineProperty from "@babel/runtime/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

export var flag = '$$_ui-hub_state';
;
export var replaceStateToAddFlag = function replaceStateToAddFlag() {
  window.history.replaceState(_objectSpread(_objectSpread({}, window.history.state || {}), {}, _defineProperty({}, flag, {
    stateBirth: false
  })), "");
};
export var pushState = function pushState() {
  window.history.pushState(_objectSpread(_objectSpread({}, window.history.state || {}), {}, _defineProperty({}, flag, {
    stateBirth: true
  })), "");
};
export var resetState = function resetState() {
  window.history.replaceState(_objectSpread(_objectSpread({}, window.history.state || {}), {}, _defineProperty({}, flag, {
    stateBirth: undefined
  })), "");
};
export var createListen = function createListen() {
  var currentState = window.history.state || {};
  var state = currentState[flag] || {};
  /**
   * 对于该工具应用在多个页面的场景，如
   * A -> B -> C
   * 其中A B都应用了该监听，那么history：
   * [A, A(stateBirth: true), B, B(stateBirth: true), C]
   * 当 C 回退时， B 页面逻辑重新执行，这个场景下，不应该再产生新的state
   */

  if (state.stateBirth === undefined) {
    replaceStateToAddFlag();
  }

  if (!state.stateBirth) {
    pushState();
  }
};

var PageBackListener = function PageBackListener(cb) {
  var _this = this;

  _classCallCheck(this, PageBackListener);

  createListen();

  var listener = function listener() {
    if (window.history.state && window.history.state[flag] && window.history.state[flag].stateBirth === false) {
      resetState();
      cb(createListen);
    }
  };

  window.addEventListener('popstate', listener); // 移除副作用

  this.removeEffect = function () {
    window.removeEventListener('popstate', listener);
  }; // 移除这整套机制


  this.removeListener = function () {
    _this.removeEffect();

    var currentState = window.history.state || {};
    var state = currentState[flag] || {};

    if (state.stateBirth) {
      window.history.go(-1);
    }
  };
};

export default PageBackListener;
